@@ -17,7 +17,7 @@ Version 0.07
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 SYNOPSIS
 
@@ -625,7 +625,8 @@ sub _get_acct {
     }
 
     unless ( defined $prefs{"password"} ) { $prefs{"password"} = "" }
-    print "Password [". $prefs{"password"} . "]: ";
+    my $password_indicator = $prefs{'password'} ? '*****' : '';
+    print "Password [". $password_indicator . "]: ";
     $res = <STDIN>; chomp $res;
     if ( $res ) {
         $prefs{"password"} = $res;
